'eeprom.wr_byte(@ticks, ticks)
'The first parameter, @ticks, tells the wr_byte method what address to write to. The method knows to write a single byte. 
'The second parameter is the value to write. 
'There are similar methods for words and longs, and master method (which is called by the others) that can write any value. 
'There are also read methods, though you're not using them in your case.
'I developed my 24xx512 object for the EFX-TEK EZ-8+ controller which uses a 64K EEPROM; the lower 32K holds the program, the upper 32K holds the user sequences.
'And, yes, you can use the 24xx512 object with a 24LC256 EEPROM -- you just have to limit your addresses to $0000..$7FFF. 


CON 
    _clkmode = xtal1 + pll16x
    _xinfreq = 5_000_000       '80 MHz

  Rx        = 31     'serial in from wx device
  Tx        = 30     'serial out to wx device
  
  SCL0      = 28
  SDA0      = 29
  
  SCL1      = 0
  SDA1      = 1
  
  SCL2      = 2
  SDA2      = 3
  
  SCL3      = 4
  SDA3      = 5

OBJ
  ser: "Parallax Serial Terminal.spin"
  eeprom: "jm_24xx512.spin"

VAR

  long  Stack1[50]

Pub Main

  ser.StartRxTx(RX, TX, 0, 115200)   'Cog #3  Parallax Serial Terminal does NOT work at receiving data 230400 for some reason.
  waitcnt(10_000_000 + cnt)   'wait 1/8 second for serial to start.

  cognew(GoEeprom, @Stack1)   '


  ser.str(string(27))     'Set command mode ANSI command for putty terminal program.                                                    
  ser.str(string("[2J"))  'Clear telnet screen.
                           
  ser.str(string(27))      'Set command mode 
  ser.str(string("[1;1f")) 'Set Position  

  Diagout


Pub GoEeprom | z
  eeprom.start(0)
  eeprom.wait
  
  Length := @Stop - @Whistle
  
  N := 0
 
 Repeat
 
  N := 0 
  Repeat N from 0 to Length
     
    eeprom.wr_long(N, Whistle[N])
    eeprom.wait
    WR1 := 0
  

  N := 0
  Repeat N from 0 to Length
     
    z:= eeprom.rd_byte(N)
    eeprom.wait
    WR1 := 1
    {


    ser.str(string(27))      'Set command mode 
    ser.str(string("[4;3f")) 'Set Position
    ser.Str(string("Value: "))
    ser.dec(Whistle[n])
    ser.Str(string("            ")) 

    ser.str(string(27))      'Set command mode 
    ser.str(string("[5;3f")) 'Set Position
    ser.Str(string("Eeprom: "))
    ser.dec(eeprom.rd_long(n))
    ser.Str(string("            ")) 
    eeprom.wait
    }    
  

Pub DiagOut

Repeat

  waitcnt(80_000_000 + cnt)   'wait 1 second.

  ser.str(string(27))      'Set command mode 
  ser.str(string("[3;3f")) 'Set Position
  ser.Str(string("Length: "))
  ser.dec(Length)
  ser.Str(string("            "))                               

  ser.str(string(27))      'Set command mode 
  ser.str(string("[4;3f")) 'Set Position
  ser.Str(string("State: "))
  If WR1 == 0
    ser.Str(string("Write"))  
  Else
    ser.Str(string("Read "))    
                              '
  ser.str(string(27))      'Set command mode 
  ser.str(string("[6;3f")) 'Set Position
  ser.Str(string("Cycle: "))
  ser.dec(N)
  ser.Str(string("            ")) 

  ser.str(string(27))      'Set command mode 
  ser.str(string("[7;3f")) 'Set Position
  ser.Str(string("Complete: "))
  Pcent:= 100 * N / Length
  ser.dec(Pcent)
  ser.Str(string("%  ")) 

Repeat

Dat
  WR1      byte 0
  Pcent   byte 0
  N       long 0
  Length  long 0
  Whistle long
  File "Lwstl.wav"
  Stop  Long 0
{{
                            TERMS OF USE: MIT License

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
}}
